classdef NNPredictor < Predictor
    %NNPREDICTOR Neural networks implementation for the predictor
    %interface.
    %   Neural networks are efficient learning algorithms they are
    %   widespread. They are capable to classification and regression too,
    %   but it cannot predict distributions for regression. (In regression
    %   they are only points in the space predicted)
    
    properties
        numHiddenNeurons;
        trainRatio;
        testRatio;
        valRatio;
        transferFunction;
    end
    
    methods
        function obj = NNPredictor(numHiddenNeurons,  trainRatio, valRatio, testRatio)
            fprintf('You have instantiated a new Neural Network predictor\n');
            
            if nargin > 4
                error('MYEXC:NeuralNetworkTooManyInputs', ...
                    'NNPredictor has at most 4 input arguments.');
            end
            
            % fill in values to ensure that NN also has 'default' constructor
            if nargin<1                
                numHiddenNeurons = 20;
            end
            if nargin <2
                trainRatio = 0.7;
            end
            if nargin <3
                valRatio = 0.2;
            end
            if nargin < 4
                testRatio = 0.1;                                                   
            end
            
            obj.isDistribution = 0;
            obj.numHiddenNeurons = numHiddenNeurons;
            obj.trainRatio = trainRatio;
            obj.testRatio = testRatio;
            obj.valRatio = valRatio;            
            obj.transferFunction = 'logsig';
        end
        
        function obj = train(obj,inputs,targets)
            disp('Train with Neural Networks');
            obj.model = newfit(inputs,targets,obj.numHiddenNeurons);

            obj.model.divideParam.trainRatio = obj.trainRatio;  
            obj.model.divideParam.valRatio = obj.valRatio;
            obj.model.divideParam.testRatio = obj.testRatio;

            obj.model.layers{1}.transferFcn = obj.transferFunction;

            % Trying to make the IW (inputWeights) determined 
            %(because it changed it's size without this)
            %net.inputs{1}.size = size(inputs,1); % It is necessary for the adopting methods.
            %net.inputs{1}.processFcns = {'mapminmax'};
            %net.outputs{2}.processFcns ={};

            % Train and Apply Network
            obj.model.trainParam.showWindow = false;
            obj.model = train(obj.model,inputs,targets);           
        end
        
        function [outputs,var] = predict(obj,inputs)
             disp('Predict with Neural Networks');
             outputs = sim(obj.model,inputs);             
             if nargout>1
                 warning('The Neural Networks predictor is called with 2 output parameters. The second one is meaningless as NN cannot provide variance.');
                 var = 0;
             end
        end
        
        function print2file(obj,f)
            fprintf(f,'MathWorks Neural Network Predictor.\n');
            fprintf(f,['It is capable to predict distributions: ' num2str(obj.isDistribution) '\n']);
            fprintf(f,'------\n');
            fprintf(f,['Number of hidden neurons: ' num2str(obj.numHiddenNeurons) '\n']);
            fprintf(f,['Train ratio: ' num2str(obj.trainRatio) '\n']);
            fprintf(f,['Test ratio: ' num2str(obj.testRatio) '\n']);
            fprintf(f,['Validation ratio: ' num2str(obj.valRatio) '\n']);
            fprintf(f,['The used transfer function is: ' obj.transferFunction '\n']);
        end
    end
    
end

