function [ outputs, variances ] = PredictGPML( model, inputs )
%PredictGPML prediction function for a 'trained' GPML model.
%   The training could be done with function: TrainGPML.
%   We suppose that we use the same parameters here as with which we
%   optimized the parameters in the training function: these parameters are
%   included in the model.
%   inputs, are in the format described in TrainModel.
%   And the outputs should be in the target format also described in
%   TrainModel.

    % check whether we trained our model with normalized inputs and if we
    % did, use the same normalization on our data.
    if model.normalization
        [inputNormalizedTransposed,model.ranges] = normalizeData(inputs',model.normalization,model.ranges);
        inputs = inputNormalizedTransposed';    
    end

    variances = zeros(size(inputs,2)*size(model.targets,2));
    for i=1:size(model.targets,2)
        [outputs(:,i), singleVar(:,i),~,~] = gp(model.hyp{i}, @infExact, model.meanfunc, model.covfunc, model.likfunc, model.inputs, model.targets(:,i), inputs');
    end
    outputs = outputs';
    for i=0:size(model.targets,2)-1
        for j=1:size(inputs,2)
            variances(i*size(inputs,2)+j,i*size(inputs,2)+j) = singleVar(j,i+1);
        end
    end
    
    %Retarnsform the normalization
    outputs = (outputs.*repmat(model.targetVariance,1,size(outputs,2)))+repmat(model.targetMean,1,size(outputs,2));

end

