function [ parameters] = Plot1OverX( inputFunctionValues, doPlot, colorLetter )
%Plot1OverX is a function which gives back the best parameters to fit a 1/x
%function to the targeted values. It can also plot the fitted curve.
%   We transform the inputFunctionValues to be closely linear fit a line on
%   that with polyfit and than transform back. y = a/x + b
%   INPUTS:
%       inputFunctionValues is an array representing the function values.
%       doPlot is a boolean which indicates whether we'd like to plot the fitting.
%       colorLetter: is a character which describes in which color we'd
%       like to plot the curve. (both the fitted and the original one)
%   OUTPUTS:
%       parameters is an array the first element is the 'a' parameter the
%       second is the 'b' (offset).

x = 1:length(inputFunctionValues);

p = polyfit(x,x.*inputFunctionValues,1);
parameters(1) = p(2);
parameters(2) = p(1);

if doPlot
    plot(inputFunctionValues,colorLetter);
    hold on;
    plot(x,parameters(1)./x+parameters(2),colorLetter);   
end

end

