function [ selectedMethod, selectedMetric ] = testingForBestCluster( features, classes, showResultTable )
% AUTHOR:	Tamas Balassa
% DATE: 	April 22, 2016
% NAME: 	testingForBestCluster
% 
% This fcn tests which is the best linkage set for the current dataset. 
% Set showResultTable to [0,1] for showing the table at the end.
%
% INPUT:
%   features            Features considered in the test.
%   classes             Classes considered in the test.
%   showResultTable     0 means do no show the table, otherwise 1.
%
% INPUT:
%   selectedMethod      Name of the Method suggested.
%   selectedMetric      Name of the Metric suggested.
%
% COPYRIGHT
% Advanced Cell Classifier (ACC) Toolbox. All rights reserved.
% Copyright (C) 2016 Peter Horvath,
% Synthetic and System Biology Unit, Hungarian Academia of Sciences,
% Biological Research Center, Szeged, Hungary; Institute for Molecular
% Medicine Finland, University of Helsinki, Helsinki, Finland.

    warning('off','all')
    method = {'average','complete','single','weighted','centroid','median','ward'};
    metric = {'euclidean','cosine','correlation','chebychev','minkowski','spearman','cityblock'};

    y1 = length(method);
    y2 = length(metric);
    matrix = zeros(y1,y2);
    min = 9999999;
    
    for i=1:length(features)
        trainingFeatures(i,:) = features{i,1};
    end
    
    for k=1:size(classes,1)
        for l=1:length(classes{1,1})
            if classes{k,1}(l) == 1;
                textData{k} = num2str(l);
            end
        end
    end
   
    waitBarHandle = waitbar(0,'Best cluster...');
    counter = 0;
    for i=1:length(method)
        for j=1:length(metric)
            counter = counter + 1;
            tree = linkage(trainingFeatures,method(i),metric(j));            
            
            fig = figure('visible','off');
            [~,~,orig] = dendrogram(tree,0,'Labels',textData);
            %[~,~,orig] = dendrogram(tree,0);
            
            for k=1:length(orig)
                t = orig(k);
                labelOrder(k) = textData(t);
            end
            
            for k=1:(length(labelOrder)-1)
                if (labelOrder{k} ~= labelOrder{k+1})
                    matrix(i,j) = matrix(i,j) + 1;
                end
            end
            donePercent = double(counter/(length(method)*length(metric)));
            waitText = sprintf('Testing each pairs...  %d%% done', int16(donePercent * 100));
            waitbar(donePercent, waitBarHandle, waitText);
        end
    end
       
    for i=1:size(matrix,1)
        for j=1:size(matrix,2)
            if matrix(i,j) < min
                min = matrix(i,j);
                selectedMethod = method{i};
                selectedMetric = metric{j};
            else 
            end
        end
    end
    
    close(waitBarHandle);
    
    if showResultTable
        figure();
        hold on;
        imagesc(matrix);
        colormap(flipud(gray));
        [a,b] = meshgrid(1:y2,1:y1);

        textStrings = num2str(matrix(:),'%0.f');
        textStrings = strtrim(cellstr(textStrings));

        hStrings = text(a(:),b(:),textStrings(:), 'HorizontalAlignment','center');
        midValue = mean(get(gca,'CLim'));
        textColors = repmat(matrix(:) > midValue,1,3);

        set(hStrings,{'Color'},num2cell(textColors,2));
        set(gca,'XTick',1:y2,'XTickLabel',metric,'YTick',1:y1,'YTickLabel',method,'TickLength',[0 0]);
    end
    
    warning('on','all')
end

