function addToTrainingSet( classPosition, featureVector )
% AUTHOR:   Tamas Balassa
% DATE:     May 18, 2016
% NAME:     addToTrainingSet
% 
% This function adds the currently selected cell to the training set.
% ClassPosition is the class index for the currently selected cell. It works
% using the variable "global CommonHandles" to extract the info of the
% currently selected cell.
%
% INPUT:
%   classPosition         It is the index of an already created class.
%   featureVector         Featurevector of the cell which will be added
%   params                Struct of parameters, if not set, read from
%                           CommonHandles
%
% COPYRIGHT
% Advanced Cell Classifier (ACC) Toolbox. All rights reserved.
% Copyright (C) 2016 Peter Horvath,
% Synthetic and System Biology Unit, Hungarian Academia of Sciences,
% Biological Research Center, Szeged, Hungary; Institute for Molecular
% Medicine Finland, University of Helsinki, Helsinki, Finland.

    global CommonHandles;
    
    saveClassificationData(classPosition,featureVector);
            
    if strcmp(CommonHandles.Classes{classPosition}.Type,'Regression')
        
        CommonHandles.RegressionPlaneHandle = regressionPlane('UserData',struct('idInTrainingSet',length(CommonHandles.TrainingSet.Features),'classIndex',classPosition,'classID',CommonHandles.Classes{classPosition}.ID,'prediction',0));
        uiwait(CommonHandles.RegressionPlaneHandle);
        
        %if the regPlane did not added the position to the training set
        if isempty(CommonHandles.TrainingSet.RegPos{end})
            %rollback
            CommonHandles.TrainingSet.MetaDataFilename(end) = [];
            CommonHandles.TrainingSet.ImageName(end) = [];
            CommonHandles.TrainingSet.OriginalImageName(end) = [];
            CommonHandles.TrainingSet.CellNumber(end) = [];
            CommonHandles.TrainingSet.Class(end) = [];
            CommonHandles.TrainingSet.Features(end) = [];
            CommonHandles.TrainingSet.Timestamp(end) = [];
            CommonHandles.TrainingSet.RegPos(end) = [];            
            classImages = CommonHandles.ClassImages(CommonHandles.Classes{classPosition}.Name);
            classImages.Images(end) = [];
            CommonHandles.ClassImages(CommonHandles.Classes{classPosition}.Name) = classImages;
            warndlg('The last annotated cell was removed from training set because the regression position was not provided.','Regression warning');
        end
        
        
        pause(0.1);                      
        %Try to jump focus back to MainGUI
        divisor = '8.4.0.150.421 (R2014b)';
        if (compareVersions(divisor,CommonHandles.MatlabVersion))
            set(CommonHandles.MainWindow,'Visible','off');                       
        end
        set(CommonHandles.MainWindow,'Visible','on');
        figure(CommonHandles.MainWindow);
        
        
    end

end