function [] = resetCommonHandlesToDefault()
% AUTHOR:	Csaba Molnar
% DATE: 	May 3, 2016
% NAME: 	resetCommonHandlesToDefault
%
% When we create a new project we must set some settings back to default.
%
% In every new release of ACC this file must be updated.
%
% COPYRIGHT
% Advanced Cell Classifier (ACC) Toolbox. All rights reserved.
% Copyright (C) 2016 Peter Horvath,
% Synthetic and System Biology Unit, Hungarian Academia of Sciences,
% Biological Research Center, Szeged, Hungary; Institute for Molecular
% Medicine Finland, University of Helsinki, Helsinki, Finland.

    global CommonHandles;

    %resetList: elements in this list are not checked whether they're in
    %the structure already but instead completly overwritten by the new
    %value.

    resetList = {...
        {'ActiveLearning','0'},...
        {'ActiveRegression','struct(''on'',0,''selectedClass'','''')'},...
        {'AL','[]'},...        
        {'ALBatched','struct(''batchSize'',5,''currentCellInBatch'',1,''data'',[],''usePCT'',1)'},...        
        {'AllCoordinates','{}'},...
        {'AllFeatures','{}'},...
        {'AllFeaturesMapping','{}'},...
        {'ALRegression','[]'},...
        {'Classes','{}'},...
        {'ClassifierNames','sacGetSupportedList(''classifiers'')'},...
        {'ClassImages','containers.Map'},...
        {'ColorView','1'},...
        {'CurrentPrediction','{}'},...
        {'Counter','0'},...
        {'DisplayAnnotatedCells','0'},...
        {'HC.Class','{}'},...
        {'HC.Default.NumberOfOutliers','100'},...
        {'HC.Default.SupportInfoIG','15'},...
        {'HC.Default.TrainParams',' ''-s 2 -t 2 -e 0.000001 -n 0.0001 -g 0.008'' '},...
        {'HC.Default.Method',' ''average'' '},...
        {'HC.Default.Metric',' ''cosine'' '},...
        {'HC.Node','{}'},...
        {'HC.Node.createClass','0'},...
        {'HC.ShowCellsFig','[]'},...
        {'MainView','struct(''Blue'',1,''Red'',1,''Green'',1,''StrechImage'',0,''StrechMin'',0,''StrechMax'',255,''StrechMinR'',0,''StrechMaxR'',255,''StrechMinG'',0,''StrechMaxG'',255,''StrechMinB'',0,''StrechMaxB'',255,''SwapMap'',1)'},...
        {'MainView.XBounds','[]'},...
        {'MainView.YBounds','[]'},...
        {'MaxCluster','0'},...
        {'LabeledInstances','[]'},...
        {'ProjectName','''default HCS project'''},...
        {'RandomTrain','0'},...
        {'RegressionPlane','[]'},...
        {'RegressionPlaneHandle','[]'},...
        {'Report','{}'},...        
        {'SALT','struct(''initialized'',CommonHandles.SALT.initialized,''folderName'',CommonHandles.SALT.folderName)'},...
        {'SelectedClassifier','1'},...
        {'SimilarCells','struct(''Images'', [], ''selected'', struct, ''sHandle'', 0)'},...        
        {'ShowCellNumbers','1'},...
        {'ShowContour','1'},...
        {'ShowHighProbCellsHandle','[]'},...
        {'ShowTrainedCellsFig','[]'},...
        {'TrainingSet.CellNumber','{}'},...
        {'TrainingSet.Class','{}'},...
        {'TrainingSet.ImageName','{}'},...
        {'TrainingSet.Features','{}'},...
        {'TrainingSet.MetaDataFilename','{}'},...
        {'TrainingSet.OriginalImageName','{}'},...
        {'TrainingSet.RegPos','{}'},...
        {'TrainingSet.Timestamp','{}'},...
        {'UploadCAMIOFigure','[]'}...
        };

    % reset cell arrays containing uicontrol objects by deleting
    for i=1:length(CommonHandles.Classbuttons)
        delete(CommonHandles.Classbuttons{1});
        delete(CommonHandles.ClassTextFields{1});
        delete(CommonHandles.ShowTrainedCells{1});
        CommonHandles.Classbuttons(1) = [];
        CommonHandles.ClassTextFields(1) = [];
        CommonHandles.ShowTrainedCells(1) = [];
    end
    
    %Delete all GUI objects reamining from the previous version (in runningCommonHandles)
    deleteGUIList = {...         
        'HC.ShowCellsFig',...
        'outlierTreeHandle',...    
        'ShowHighProbCellsHandle',...
        'ShowSimilarCellsHandle',...
        'ShowTrainedCellsFig',...        
        'RegressionPlaneHandle',...
        };
    for i=1:length(deleteGUIList)
        if (isfieldRecursive(CommonHandles,deleteGUIList{i}))
            isOpened = eval(['ishandle(CommonHandles.' deleteGUIList{i} ')']);
            if (isOpened)
                eval(['delete(CommonHandles.',deleteGUIList{i},')']);
            end        
        end 
    end
    
    % reset fields
    for i=1:length(resetList)
        eval(['CommonHandles.' , resetList{i}{1} , '=', resetList{i}{2} ';']);
    end
            
end